package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.jna.LibBootromByJNA;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IFrameSetting;
import com.vendor.burn.serial.workers.FastbootBurnerWorker;
import java.nio.charset.StandardCharsets;
import org.eclipse.core.runtime.SubMonitor;
import org.eclipse.swt.widgets.Display;

public class CallLibBootromWorker extends FastbootBurnerWorker {
  public static final LibBootromByJNA.JavaCallbackCancel callbackCancel = (LibBootromByJNA.JavaCallbackCancel)new Object();
  
  public static final LibBootromByJNA.JavaCallbackAdd callback = (LibBootromByJNA.JavaCallbackAdd)new Object();
  
  private static final int NO_CARE_CHAR = -1;
  
  private static final int FILE_INFO_LEN = 1024;
  
  private static long comFd = -1L;
  
  private static long udpFd = -1L;
  
  private static long socketFd = -1L;
  
  private static long usbFd = -1L;
  
  private static TransmissionMode transmissionMode = TransmissionMode.SERIAL;
  
  private static SubMonitor subMonitor;
  
  public CallLibBootromWorker(IFrameSetting frameSetting, IBurner burner, SubMonitor subProgressMonitor) {
    super(frameSetting, burner);
    setSubMonitor(subProgressMonitor);
    String osName = System.getProperties().getProperty("os.name");
    if (osName.toLowerCase().startsWith("windows")) {
      System.setProperty("jna.encoding", "GBK");
    } else {
      System.setProperty("jna.encoding", "UTF-8");
    } 
  }
  
  public static void setComFd(long comFd) {
    com.vendor.burn.serial.workers.CallLibBootromWorker.comFd = comFd;
  }
  
  public static long getComFd() {
    return comFd;
  }
  
  public static long getSocketFd() {
    return socketFd;
  }
  
  public static void setSocketFd(long socketFd) {
    com.vendor.burn.serial.workers.CallLibBootromWorker.socketFd = socketFd;
  }
  
  public static long getUdpFd() {
    return udpFd;
  }
  
  public static void setUdpFd(long udpFd) {
    com.vendor.burn.serial.workers.CallLibBootromWorker.udpFd = udpFd;
  }
  
  public static long getUsbFd() {
    return usbFd;
  }
  
  public static void setUsbFd(long usbFd) {
    com.vendor.burn.serial.workers.CallLibBootromWorker.usbFd = usbFd;
  }
  
  public static long getFd() {
    if (transmissionMode == TransmissionMode.USB)
      return usbFd; 
    if (transmissionMode == TransmissionMode.UDP)
      return udpFd; 
    if (transmissionMode == TransmissionMode.SOCKET)
      return socketFd; 
    return comFd;
  }
  
  public static int getSerialPortList(byte[] comName, int length) {
    return LibBootromByJNA.instance.GetSerialPortList(comName, length);
  }
  
  public static boolean openSerialComm(String comName, int baudRate) {
    long burnResult = LibBootromByJNA.instance.OpenSerialComm(comName, baudRate);
    setComFd(burnResult);
    if (burnResult == 0L) {
      Log.infoln("open serial failed");
      return false;
    } 
    transmissionMode = TransmissionMode.SERIAL;
    return true;
  }
  
  public static boolean createSerialPortServer(String ip, int port) {
    long burnResult = LibBootromByJNA.instance.CreateSerialPortServer(ip, port);
    setSocketFd(burnResult);
    if (burnResult == 0L) {
      Log.infoln("open socket failed");
      return false;
    } 
    transmissionMode = TransmissionMode.SOCKET;
    return true;
  }
  
  public static boolean createUdpSocket(String ip, int port) {
    long burnResult = LibBootromByJNA.instance.CreateUdpSocket(ip, port);
    if (burnResult == 0L) {
      Log.infoln("open udp failed");
      return false;
    } 
    setUdpFd(burnResult);
    transmissionMode = TransmissionMode.UDP;
    return true;
  }
  
  public static boolean openUsbDevice(int vid, int pid, String usbDeviceName) {
    long burnResult = LibBootromByJNA.instance.OpenUsbDevice(vid, pid, usbDeviceName);
    if (burnResult == 0L) {
      Display.getDefault().syncExec((Runnable)new Object());
      return false;
    } 
    setUsbFd(burnResult);
    transmissionMode = TransmissionMode.USB;
    return true;
  }
  
  public static boolean destroyDevice(long comFd) {
    int burnResult = LibBootromByJNA.instance.DestroyDevice(comFd);
    if (burnResult == -1)
      return false; 
    return true;
  }
  
  public static boolean sendCmd(long comFd, String command, int dataLen, int isRepley, int timeout) {
    int burnResult = LibBootromByJNA.instance.SendCmd(comFd, command, dataLen, isRepley, timeout);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean sendBytes(long comFd, byte[] data, int dataLen) {
    int burnResult = LibBootromByJNA.instance.SendBytes(comFd, data, dataLen);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean recvCmd(long comFd, byte[] data, int dataLen) {
    int burnResult = LibBootromByJNA.instance.RecvCmd(comFd, data, dataLen);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean recevieBytes(long comFd, byte[] data, int dataLen) {
    int burnResult = LibBootromByJNA.instance.RecevieBytes(comFd, data, dataLen);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static void setChipType(int chipDepartment, int chipType) {
    LibBootromByJNA.instance.SetChipType(chipDepartment, chipType);
  }
  
  public static void setDdrOrFlash(int ddrOrFlash) {
    LibBootromByJNA.instance.SetDdrOrFlash(ddrOrFlash);
  }
  
  public static void setPacketSize(int packetSize) {
    LibBootromByJNA.instance.SetPacketSize(packetSize);
  }
  
  public static void setReboot(int isReboot) {
    LibBootromByJNA.instance.SetReboot(isReboot);
  }
  
  public static void setDllPath(String dllPath) {
    LibBootromByJNA.instance.SetDllPath(dllPath);
  }
  
  public static void setTypeFrameFrequency(int dwTimeout) {
    LibBootromByJNA.instance.SetTypeFrameFrequency(dwTimeout);
  }
  
  public static void setTypeFrameTimeout(int dwTimeout) {
    LibBootromByJNA.instance.SetTypeFrameTimeout(dwTimeout);
  }
  
  public static void setBeforeBurningDelayTime(int beforeBurningDelayTime) {
    LibBootromByJNA.instance.SetBeforeBurningDelayTime(beforeBurningDelayTime);
  }
  
  public static void setBurnFileIndex(int index) {
    LibBootromByJNA.instance.SetBurnFileIndex(index);
  }
  
  public static void setSerialParam(int stopBit, int parity) {
    LibBootromByJNA.instance.SetSerialParam(stopBit, parity);
  }
  
  public static boolean sendReset(long device) {
    int burnResult = LibBootromByJNA.instance.SendReset(device);
    if (burnResult != 0)
      return true; 
    return false;
  }
  
  public static boolean bootromBootDownload(long comFd, String filePath) {
    int burnResult = LibBootromByJNA.instance.BootromBootDownload(comFd, filePath);
    if (burnResult == 1)
      return true; 
    if (burnResult == 0) {
      returnError(Messages.SERAIL_PORT_BOOT_NOT_RUN);
    } else {
      Log.printErrorInfo(burnResult);
    } 
    return false;
  }
  
  public static boolean bootDownloadByLib(long comFd, int ddrOrFlash, String filePath, int[] caType, long[] initDdrAddr) {
    setDdrOrFlash(ddrOrFlash);
    int burnResult = LibBootromByJNA.instance.BootromBootDownload(comFd, filePath);
    if (burnResult == 1) {
      caType[0] = isCa(comFd);
      initDdrAddr[0] = getBootDdrAddr(comFd);
      return true;
    } 
    if (burnResult == 0) {
      returnError(Messages.SERAIL_PORT_BOOT_NOT_RUN);
    } else {
      Log.printErrorInfo(burnResult);
    } 
    return false;
  }
  
  public static boolean bootDownloadByLib(long comFd, int ddrOrFlash, String filePath, long[] initDdrAddr) {
    setDdrOrFlash(ddrOrFlash);
    int burnResult = LibBootromByJNA.instance.BootromBootDownload(comFd, filePath);
    if (burnResult == 1) {
      initDdrAddr[0] = getBootDdrAddr(comFd);
      return true;
    } 
    if (burnResult == 0) {
      returnError(Messages.SERAIL_PORT_BOOT_NOT_RUN);
    } else {
      Log.printErrorInfo(burnResult);
    } 
    return false;
  }
  
  public static boolean bootromBootDownloadEX(long device, byte[] data, long len, long burnAddress) {
    int burnResult = LibBootromByJNA.instance.BootromBootDownloadEX(device, data, len, burnAddress);
    if (burnResult != 0)
      return true; 
    return false;
  }
  
  public static boolean downloadEX(long device, byte[] data, long len, long burnAddress) {
    int burnResult = LibBootromByJNA.instance.DownloadEX(device, data, len, burnAddress);
    if (burnResult != 0)
      return true; 
    return false;
  }
  
  public static long getBootDdrAddr(long comFd) {
    return LibBootromByJNA.instance.GetBootDdrAddr(comFd);
  }
  
  public static int isCa(long comFd) {
    return LibBootromByJNA.instance.IsCa(comFd);
  }
  
  public static boolean downloadData(long comFd, String fileName, int ddrAddress) {
    int burnResult = LibBootromByJNA.instance.DownloadData(comFd, fileName, ddrAddress);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean uploadFileEx(long comFd, long flashAddr, long length, String fileName) {
    int burnResult = LibBootromByJNA.instance.UploadFile(comFd, 0, flashAddr, length, fileName);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean uploadFile(long comFd, int bootDdrAddr, long flashAddr, long length, String fileName) {
    int burnResult = LibBootromByJNA.instance.UploadFile(comFd, bootDdrAddr, flashAddr, length, fileName);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean uploadFileByUsbTftp(long comFd, String fileName) {
    int burnResult = LibBootromByJNA.instance.UploadFileByUsbTftp(comFd, fileName);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean splitSparseFile(String fileName, String fileSystem, long address, long length) {
    int burnResult = LibBootromByJNA.instance.SplitSparseFile(fileName, fileSystem, address, length);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean splitYaffsFile(String fileName, String fileSystem, long address, long length, long[] yaffsPageAndOobSize) {
    long page = yaffsPageAndOobSize[0];
    long oob = yaffsPageAndOobSize[1];
    int burnResult = LibBootromByJNA.instance.SplitYaffsFile(fileName, fileSystem, address, length, page, oob);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean getSparseFileXmlList(String fileName, byte[] sparseFileXmlList) {
    int burnResult = LibBootromByJNA.instance.GetSparseFileXmlList(fileName, sparseFileXmlList);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static SubMonitor getSubMonitor() {
    return subMonitor;
  }
  
  public static void setSubMonitor(SubMonitor subMonitor) {
    com.vendor.burn.serial.workers.CallLibBootromWorker.subMonitor = subMonitor;
  }
  
  public static String[] resolveAllinoneImage(String fileName) {
    byte[] fileInfo = new byte[1024];
    int result = LibBootromByJNA.instance.ParsePartition(fileName, fileInfo, 1024);
    if (result == 1)
      return (new String(fileInfo, StandardCharsets.UTF_8)).trim().split(";"); 
    return new String[0];
  }
}
